# Sage version information for shell scripts.
#
# #31049: The following line is valid shell code but not valid Python code,
# which stops "setup.py develop" from rewriting it as a Python file.
:
# This file is auto-generated by the sage-update-version script, do not edit!
SAGE_VERSION='10.0.beta8'
SAGE_RELEASE_DATE='2023-04-06'
SAGE_VERSION_BANNER='SageMath version 10.0.beta8, Release Date: 2023-04-06'
